@@ -1,4 +1,4 @@
-`BootT.PI` <-
+BootT.PI <-
 function(x,p,h,nboot,prob)
 {
 set.seed(12345)
