@@ -1,4 +1,4 @@
-`Plot.PI` <-
+Plot.PI <-
 function(x,fore,Interval,start,end,frequency)
 {
 library(zoo)
@@ -13,6 +13,7 @@ fend <- m1[length(m1)]+h/frequency
 y2 <- zooreg(fore,fstart,fend,frequency)
 y3 <- zooreg(Interval,fstart,fend,frequency)
 ts.plot(ts(y1,start,end,frequency),ts(y2,fstart,fend,frequency),ts(y3,fstart,fend,frequency),lwd=c(1,rep(2,1+ncol(Interval))),col=c(1,4,rep(2,ncol(Interval))))
+title(main="Time Plot and Prediction Intervals",sub="red = prediction quantiles; blue = point forecasts", col.sub=2)
 abline(v=fstart,col=3,lwd=2)
 }
 
