@@ -1,4 +1,4 @@
-`mainf` <- 
+mainf <-
 function(b,h,p)
 {
     mf <- c(1, b[1], rep(0,h-1))
@@ -8,4 +8,5 @@ function(b,h,p)
         mf[i+1] <- sum(b[idx] * rev(mf[1:i])[idx])
     }
     return(mf)
-}
\ No newline at end of file
+}
+
